activation

package
v0.0.0-...-a31b887 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2018 License: GPL-3.0 Imports: 2 Imported by: 24

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SupportedActivationFunctions

func SupportedActivationFunctions() []string

SupportedActivationFunctions returns the list of activation functions supported by GoMind.

func ValidFunction

func ValidFunction(name string) string

ValidFunction returns the valid GoMind name of the given activation function's name.

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service type defines a new activation service for the GoMind neural network.

func New

func New(name string) (*Service, error)

New creates a new activation service of the given activation function name.

func (*Service) Name

func (s *Service) Name() string

Name returns the string name of the activation service.

Jump to